@@ -18,11 +18,11 @@ Device::USB::Device - Use libusb to access USB devices.
 
 =head1 VERSION
 
-Version 0.20
+Version 0.36
 
 =cut
 
-our $VERSION=0.20;
+our $VERSION=0.36;
 
 
 =head1 SYNOPSIS
@@ -684,6 +684,7 @@ sub bulk_read
     my $self = shift;
     # Don't change to shifts, I need to write back to $bytes.
     my ($ep, $bytes, $size, $timeout) = @_;
+    $bytes = q{} unless defined $bytes;
 
     $self->_assert_open();
 
@@ -735,6 +736,7 @@ sub interrupt_read
     my $self = shift;
     # Don't change to shifts, I need to write back to $bytes.
     my ($ep, $bytes, $size, $timeout) = @_;
+    $bytes = q{} unless defined $bytes;
 
     $self->_assert_open();
 
@@ -908,7 +910,7 @@ that is the entire reason for the module's existence.
 
 =head1 AUTHOR
 
-G. Wade Johnson (wade at anomaly dot org)
+G. Wade Johnson (gwadej at cpan dot org)
 Paul Archer (paul at paularcher dot org)
 
 Houston Perl Mongers Group
@@ -929,7 +931,7 @@ and helped with the development.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006 Houston Perl Mongers
+Copyright 2006-2013 Houston Perl Mongers
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
